fnss.topologies.topology.DirectedTopology.out_edges — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.DirectedTopology.out_edges

`DirectedTopology.` `out_edges`(nbunch=None, data=False)

  Return a list of edges.

  Edges are returned as tuples with optional data in the order (node, neighbor, data).

  Parameters : | nbunch : iterable container, optional (default= all nodes) A container of nodes. The container will be iterated through once. data : bool, optional (default=False) Return two tuples (u,v) (False) or three-tuples (u,v,data) (True).
  Returns : | edge_list: list of edge tuples : Edges that are adjacent to any node in nbunch, or a list of all edges if nbunch is not specified.

  See also

  `edges_iter`
    return an iterator over the edges

  Notes

  Nodes in nbunch that are not in the graph will be (quietly) ignored. For directed graphs this returns the out-edges.

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> G.edges()
      [(0, 1), (1, 2), (2, 3)]
      >>> G.edges(data=True) # default edge data is {} (empty dictionary)
      [(0, 1, {}), (1, 2, {}), (2, 3, {})]
      >>> G.edges([0,3])
      [(0, 1), (3, 2)]
      >>> G.edges(0)
      [(0, 1)]

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »